#include <Kafka_Provider.h>
using std::chrono::milliseconds;


KafkaProvider::KafkaProvider(){
	setTopic("DAQ_topic");
	this->config = {
			{ "metadata.broker.list", "127.0.0.1:9092" }
	};
	builders[getTopic()] = new MessageBuilder(getTopic());
	this->producer = new BufferedProducer<std::string>(this->config);
}

KafkaProvider::KafkaProvider(std::string ip, int port, std::string topic){
	setTopic(topic);
	std::string ip_port = ip.append(":").append(std::to_string(port));
	this->config = {
			{ "metadata.broker.list", ip_port }
	};
	builders[getTopic()] = new MessageBuilder(getTopic());
	this->producer = new BufferedProducer<std::string>(this->config);
}

void KafkaProvider::setTopic(std::string topic){
	this->topic = topic;
	try{
		builders.at(topic);
	}
	catch(const std::out_of_range& oor){
		builders[topic] = new MessageBuilder(getTopic());
	}
}


int KafkaProvider::write(BasePacket &packet){
	producer->produce(builders.at(getTopic())->payload(Buffer((char*)packet.getBufferPtr(),packet.getPacketSize())));
	return 1;
}

int KafkaProvider::write(BasePacket &packet, std::string dest){
	producer->produce(builders.at(dest)->payload(Buffer((char*)packet.getBufferPtr(),packet.getPacketSize())));
	return 1;
}

int KafkaProvider::open(){
	builders.at(getTopic())->topic(getTopic()).partition(0);
	return 1;
}

int KafkaProvider::close(){
	std::cout << "FLUSHING " << std::endl;
	milliseconds sec(10000);
	producer->flush(sec);
	return 1;
}